.. Copyright (C) 2013-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.console`` role manages miscellaneous preferences related to the
Linux console and CLI environment.
